@@ -13,9 +13,14 @@ from .ebs import *
 
 from .common import *
 from .draw import *
-from .font import *
-from .gui import *
+from .bitmapfont import *
+from .ttf import *
+from .uisystem import *
+from .msgbox import *
 from .image import *
 from .pixelaccess import *
+from .renderer import *
 from .sprite import *
+from .spritesystem import *
+from .surface import *
 from .window import *
