@@ -1,12 +1,12 @@
 import os
 import sys
 import pytest
+import sdl2
 from ctypes import cast, c_char_p, addressof
-from sdl2 import filesystem, SDL_free
 
 
 def test_SDL_GetBasePath():
-    path = filesystem.SDL_GetBasePath()
+    path = sdl2.SDL_GetBasePath()
     path = path.decode("utf-8")
     if sys.version_info[0] < 3:
         is_python_path = False
@@ -20,7 +20,7 @@ def test_SDL_GetBasePath():
         assert execprefix.lower() in path.lower()
 
 def test_SDL_GetPrefPath():
-    path = filesystem.SDL_GetPrefPath(b"OrgName", b"AppName")
+    path = sdl2.SDL_GetPrefPath(b"OrgName", b"AppName")
     path = path.decode("utf-8")
     assert "OrgName" in path
     assert "AppName" in path
