@@ -6,7 +6,6 @@ from sdl2 import SDL_Init, SDL_Quit, SDL_INIT_JOYSTICK
 from sdl2.events import SDL_QUERY, SDL_ENABLE, SDL_IGNORE
 from sdl2.stdinc import SDL_TRUE, SDL_FALSE
 from sdl2.error import SDL_GetError, SDL_ClearError
-from sdl2 import joystick
 
 # Get status of joystick support/availability before running tests
 any_joysticks = False
@@ -14,7 +13,7 @@ SDL_ClearError()
 ret = SDL_Init(SDL_INIT_JOYSTICK)
 joystick_works = ret == 0 and SDL_GetError() == b""
 if joystick_works:
-    devices = joystick.SDL_NumJoysticks()
+    devices = sdl2.SDL_NumJoysticks()
     if sdl2.dll.version >= 2014:
         # On 2.0.14 and above, we can test with a virtual joystick
         devices += 1
@@ -24,16 +23,16 @@ SDL_Quit()
 pytestmark = pytest.mark.skipif(not joystick_works, reason="system unsupported")
 
 joystick_types = [
-    joystick.SDL_JOYSTICK_TYPE_UNKNOWN,
-    joystick.SDL_JOYSTICK_TYPE_GAMECONTROLLER,
-    joystick.SDL_JOYSTICK_TYPE_WHEEL,
-    joystick.SDL_JOYSTICK_TYPE_ARCADE_STICK,
-    joystick.SDL_JOYSTICK_TYPE_FLIGHT_STICK,
-    joystick.SDL_JOYSTICK_TYPE_DANCE_PAD,
-    joystick.SDL_JOYSTICK_TYPE_GUITAR,
-    joystick.SDL_JOYSTICK_TYPE_DRUM_KIT,
-    joystick.SDL_JOYSTICK_TYPE_ARCADE_PAD,
-    joystick.SDL_JOYSTICK_TYPE_THROTTLE,
+    sdl2.SDL_JOYSTICK_TYPE_UNKNOWN,
+    sdl2.SDL_JOYSTICK_TYPE_GAMECONTROLLER,
+    sdl2.SDL_JOYSTICK_TYPE_WHEEL,
+    sdl2.SDL_JOYSTICK_TYPE_ARCADE_STICK,
+    sdl2.SDL_JOYSTICK_TYPE_FLIGHT_STICK,
+    sdl2.SDL_JOYSTICK_TYPE_DANCE_PAD,
+    sdl2.SDL_JOYSTICK_TYPE_GUITAR,
+    sdl2.SDL_JOYSTICK_TYPE_DRUM_KIT,
+    sdl2.SDL_JOYSTICK_TYPE_ARCADE_PAD,
+    sdl2.SDL_JOYSTICK_TYPE_THROTTLE,
 ]
 
 
@@ -47,32 +46,32 @@ def with_sdl():
     assert ret == 0
     # Also initialize a virtual joystick (if supported)
     if sdl2.dll.version >= 2014:
-        virt_type = joystick.SDL_JOYSTICK_TYPE_GAMECONTROLLER
-        virt_index = joystick.SDL_JoystickAttachVirtual(virt_type, 2, 4, 1)
+        virt_type = sdl2.SDL_JOYSTICK_TYPE_GAMECONTROLLER
+        virt_index = sdl2.SDL_JoystickAttachVirtual(virt_type, 2, 4, 1)
     yield
     sdl2.SDL_Quit()
 
 @pytest.fixture()
 def joysticks(with_sdl):
     devices = []
-    count = joystick.SDL_NumJoysticks()
+    count = sdl2.SDL_NumJoysticks()
     for i in range(count):
-        stick = joystick.SDL_JoystickOpen(i)
+        stick = sdl2.SDL_JoystickOpen(i)
         assert sdl2.SDL_GetError() == b""
-        assert isinstance(stick.contents, joystick.SDL_Joystick)
+        assert isinstance(stick.contents, sdl2.SDL_Joystick)
         devices.append(stick)
     yield devices
     for stick in devices:
-        joystick.SDL_JoystickClose(stick)
+        sdl2.SDL_JoystickClose(stick)
 
 def is_virtual(stick):
     virtual = False
     if isinstance(stick, int):
         if sdl2.dll.version >= 2014:
-            virtual = joystick.SDL_JoystickIsVirtual(stick) == SDL_TRUE
-    elif isinstance(stick.contents, joystick.SDL_Joystick):
-        name = joystick.SDL_JoystickName(stick)
-        virtual = name == b"Virtual Joystick"
+            virtual = sdl2.SDL_JoystickIsVirtual(stick) == SDL_TRUE
+    elif isinstance(stick.contents, sdl2.SDL_Joystick):
+        name = sdl2.SDL_JoystickName(stick)
+        virtual = name in [b"Virtual Joystick", b"Virtual Controller"]
     return virtual
 
 
@@ -81,212 +80,212 @@ def is_virtual(stick):
 def test_SDL_JoystickGetGUIDFromString():
     guid_str = b'030000007e050000060300001c3a0000' # Wiimote on macOS
     expected = [3, 0, 0, 0, 126, 5, 0, 0, 6, 3, 0, 0, 28, 58, 0, 0]
-    guid = joystick.SDL_JoystickGetGUIDFromString(guid_str)
+    guid = sdl2.SDL_JoystickGetGUIDFromString(guid_str)
     assert list(guid.data) == expected
 
 def test_SDL_JoystickGetGUIDString():
     guid_str = b'030000007e050000060300001c3a0000' # Wiimote on macOS
-    guid = joystick.SDL_JoystickGetGUIDFromString(guid_str)
+    guid = sdl2.SDL_JoystickGetGUIDFromString(guid_str)
     buff = create_string_buffer(33)
-    joystick.SDL_JoystickGetGUIDString(guid, buff, 33) # Get GUID string
+    sdl2.SDL_JoystickGetGUIDString(guid, buff, 33) # Get GUID string
     assert guid_str == buff.value
 
 def test_SDL_NumJoysticks():
     if SDL_Init(SDL_INIT_JOYSTICK) != 0:
         pytest.skip("joystick subsystem not supported")
-    retval = joystick.SDL_NumJoysticks()
+    retval = sdl2.SDL_NumJoysticks()
     SDL_Quit()
     assert retval >= 0
 
 def test_SDL_JoystickNameForIndex(with_sdl):
-    count = joystick.SDL_NumJoysticks()
+    count = sdl2.SDL_NumJoysticks()
     for index in range(count):
-        name = joystick.SDL_JoystickNameForIndex(index)
+        name = sdl2.SDL_JoystickNameForIndex(index)
         assert type(name) in (str, bytes)
 
 def test_SDL_JoystickOpenClose(with_sdl):
-    count = joystick.SDL_NumJoysticks()
+    count = sdl2.SDL_NumJoysticks()
     for index in range(count):
-        stick = joystick.SDL_JoystickOpen(index)
-        assert isinstance(stick.contents, joystick.SDL_Joystick)
-        joystick.SDL_JoystickClose(stick)
+        stick = sdl2.SDL_JoystickOpen(index)
+        assert isinstance(stick.contents, sdl2.SDL_Joystick)
+        sdl2.SDL_JoystickClose(stick)
 
 def test_SDL_JoystickName(joysticks):
     names = []
     for stick in joysticks:
-        name = joystick.SDL_JoystickName(stick)
+        name = sdl2.SDL_JoystickName(stick)
         assert type(name) in (str, bytes)
         names.append(name.decode('utf-8'))
     print(names)
 
 def test_SDL_JoystickGetDeviceGUID(with_sdl):
-    count = joystick.SDL_NumJoysticks()
+    count = sdl2.SDL_NumJoysticks()
     for index in range(count):
-        guid = joystick.SDL_JoystickGetDeviceGUID(index)
-        assert isinstance(guid, joystick.SDL_JoystickGUID)
+        guid = sdl2.SDL_JoystickGetDeviceGUID(index)
+        assert isinstance(guid, sdl2.SDL_JoystickGUID)
         guidlist = list(guid.data)
         assert isinstance(guidlist[0], int)
 
 def test_SDL_JoystickGetGUID(joysticks):
     for stick in joysticks:
-        guid = joystick.SDL_JoystickGetGUID(stick)
-        assert isinstance(guid, joystick.SDL_JoystickGUID)
+        guid = sdl2.SDL_JoystickGetGUID(stick)
+        assert isinstance(guid, sdl2.SDL_JoystickGUID)
         guidlist = list(guid.data)
         assert isinstance(guidlist[0], int)
 
 def test_SDL_JoystickGetAttached(joysticks):
     for stick in joysticks:
-        ret = joystick.SDL_JoystickGetAttached(stick)
+        ret = sdl2.SDL_JoystickGetAttached(stick)
         assert ret in [SDL_FALSE, SDL_TRUE]
 
 def test_SDL_JoystickInstanceID(joysticks):
     for stick in joysticks:
-        ret = joystick.SDL_JoystickInstanceID(stick)
+        ret = sdl2.SDL_JoystickInstanceID(stick)
         assert ret >= 0
 
 def test_SDL_JoystickNumAxes(joysticks):
     for stick in joysticks:
-        assert isinstance(stick.contents, joystick.SDL_Joystick)
-        axes = joystick.SDL_JoystickNumAxes(stick)
+        assert isinstance(stick.contents, sdl2.SDL_Joystick)
+        axes = sdl2.SDL_JoystickNumAxes(stick)
         assert axes >= 0
         if is_virtual(stick):
             assert axes == 2
 
 def test_SDL_JoystickNumBalls(joysticks):
     for stick in joysticks:
-        assert isinstance(stick.contents, joystick.SDL_Joystick)
-        balls = joystick.SDL_JoystickNumBalls(stick)
+        assert isinstance(stick.contents, sdl2.SDL_Joystick)
+        balls = sdl2.SDL_JoystickNumBalls(stick)
         assert balls >= 0
 
 def test_SDL_JoystickNumHats(joysticks):
     for stick in joysticks:
-        assert isinstance(stick.contents, joystick.SDL_Joystick)
-        hats = joystick.SDL_JoystickNumHats(stick)
+        assert isinstance(stick.contents, sdl2.SDL_Joystick)
+        hats = sdl2.SDL_JoystickNumHats(stick)
         assert hats >= 0
         if is_virtual(stick):
             assert hats == 1
 
 def test_SDL_JoystickNumButtons(joysticks):
     for stick in joysticks:
-        assert isinstance(stick.contents, joystick.SDL_Joystick)
-        buttons = joystick.SDL_JoystickNumButtons(stick)
+        assert isinstance(stick.contents, sdl2.SDL_Joystick)
+        buttons = sdl2.SDL_JoystickNumButtons(stick)
         assert buttons >= 0
         if is_virtual(stick):
             assert buttons == 4
 
 def test_SDL_JoystickUpdate(with_sdl):
     # NOTE: Returns void, can't really test anything else
-    joystick.SDL_JoystickUpdate()
+    sdl2.SDL_JoystickUpdate()
     assert SDL_GetError() == b""
 
 def test_SDL_JoystickEventState(with_sdl):
     for state in (SDL_IGNORE, SDL_ENABLE):
-        news = joystick.SDL_JoystickEventState(state)
+        news = sdl2.SDL_JoystickEventState(state)
         assert news == state
-        query = joystick.SDL_JoystickEventState(SDL_QUERY)
+        query = sdl2.SDL_JoystickEventState(SDL_QUERY)
         assert query == state
 
 def test_SDL_JoystickGetAxis(joysticks):
     for stick in joysticks:
-        for axis in range(joystick.SDL_JoystickNumAxes(stick)):
-            val = joystick.SDL_JoystickGetAxis(stick, axis)
+        for axis in range(sdl2.SDL_JoystickNumAxes(stick)):
+            val = sdl2.SDL_JoystickGetAxis(stick, axis)
             assert -32768 <= val <= 32767
 
 def test_SDL_JoystickGetBall(joysticks):
-    numball = [joystick.SDL_JoystickNumBalls(s) for s in joysticks]
+    numball = [sdl2.SDL_JoystickNumBalls(s) for s in joysticks]
     if not any(numball):
         pytest.skip("no trackball on any connected controller")
     dx, dy = c_int(0), c_int(0)
-    get_ball = joystick.SDL_JoystickGetBall
+    get_ball = sdl2.SDL_JoystickGetBall
     for stick in sticks:
-        for ball in range(joystick.SDL_JoystickNumBalls(stick)):
+        for ball in range(sdl2.SDL_JoystickNumBalls(stick)):
             ret = get_ball(stick, ball, byref(dx), byref(dy))
             assert SDL_GetError() == b""
             assert ret == 0
 
 def test_SDL_JoystickGetHat(joysticks):
     hatvals = [
-        joystick.SDL_HAT_UP, joystick.SDL_HAT_DOWN, joystick.SDL_HAT_LEFT,
-        joystick.SDL_HAT_RIGHT, joystick.SDL_HAT_CENTERED,
-        joystick.SDL_HAT_LEFTUP, joystick.SDL_HAT_LEFTDOWN,
-        joystick.SDL_HAT_RIGHTUP, joystick.SDL_HAT_RIGHTDOWN
+        sdl2.SDL_HAT_UP, sdl2.SDL_HAT_DOWN, sdl2.SDL_HAT_LEFT,
+        sdl2.SDL_HAT_RIGHT, sdl2.SDL_HAT_CENTERED,
+        sdl2.SDL_HAT_LEFTUP, sdl2.SDL_HAT_LEFTDOWN,
+        sdl2.SDL_HAT_RIGHTUP, sdl2.SDL_HAT_RIGHTDOWN
     ]
     for stick in joysticks:
-        for hat in range(joystick.SDL_JoystickNumHats(stick)):
-            val = joystick.SDL_JoystickGetHat(stick, hat)
+        for hat in range(sdl2.SDL_JoystickNumHats(stick)):
+            val = sdl2.SDL_JoystickGetHat(stick, hat)
             assert val in hatvals
 
 def test_SDL_JoystickGetButton(joysticks):
     for stick in joysticks:
-        for button in range(joystick.SDL_JoystickNumButtons(stick)):
-            val = joystick.SDL_JoystickGetButton(stick, button)
+        for button in range(sdl2.SDL_JoystickNumButtons(stick)):
+            val = sdl2.SDL_JoystickGetButton(stick, button)
             assert val in [0, 1]
 
 def test_SDL_JoystickCurrentPowerLevel(joysticks):
     levels = [
-        joystick.SDL_JOYSTICK_POWER_UNKNOWN,
-        joystick.SDL_JOYSTICK_POWER_EMPTY,
-        joystick.SDL_JOYSTICK_POWER_LOW,
-        joystick.SDL_JOYSTICK_POWER_MEDIUM,
-        joystick.SDL_JOYSTICK_POWER_FULL,
-        joystick.SDL_JOYSTICK_POWER_WIRED,
-        joystick.SDL_JOYSTICK_POWER_MAX,
+        sdl2.SDL_JOYSTICK_POWER_UNKNOWN,
+        sdl2.SDL_JOYSTICK_POWER_EMPTY,
+        sdl2.SDL_JOYSTICK_POWER_LOW,
+        sdl2.SDL_JOYSTICK_POWER_MEDIUM,
+        sdl2.SDL_JOYSTICK_POWER_FULL,
+        sdl2.SDL_JOYSTICK_POWER_WIRED,
+        sdl2.SDL_JOYSTICK_POWER_MAX,
     ]
     for stick in joysticks:
-        pwr = joystick.SDL_JoystickCurrentPowerLevel(stick)
+        pwr = sdl2.SDL_JoystickCurrentPowerLevel(stick)
         assert SDL_GetError() == b""
         assert pwr in levels
 
 def test_SDL_JoystickFromInstanceID(joysticks):
     for stick in joysticks:
-        iid = joystick.SDL_JoystickInstanceID(stick)
+        iid = sdl2.SDL_JoystickInstanceID(stick)
         assert iid >= 0
-        stick2 = joystick.SDL_JoystickFromInstanceID(iid)
-        name = joystick.SDL_JoystickName(stick)
-        assert joystick.SDL_JoystickName(stick2) == name
+        stick2 = sdl2.SDL_JoystickFromInstanceID(iid)
+        name = sdl2.SDL_JoystickName(stick)
+        assert sdl2.SDL_JoystickName(stick2) == name
 
 @pytest.mark.skipif(sdl2.dll.version < 2012, reason="not available")
 def test_SDL_JoystickFromPlayerIndex(joysticks):
     i = 0
     for stick in joysticks:
-        joystick.SDL_JoystickSetPlayerIndex(stick, i)
-        stick2 = joystick.SDL_JoystickFromPlayerIndex(i)
-        name = joystick.SDL_JoystickName(stick)
-        assert joystick.SDL_JoystickName(stick2) == name
+        sdl2.SDL_JoystickSetPlayerIndex(stick, i)
+        stick2 = sdl2.SDL_JoystickFromPlayerIndex(i)
+        name = sdl2.SDL_JoystickName(stick)
+        assert sdl2.SDL_JoystickName(stick2) == name
         i += 1
 
 def test_SDL_JoystickGetVendor(joysticks):
     for stick in joysticks:
-        vid = joystick.SDL_JoystickGetVendor(stick)
+        vid = sdl2.SDL_JoystickGetVendor(stick)
         assert SDL_GetError() == b""
         if not is_virtual(stick):
             assert vid > 0
 
 def test_SDL_JoystickGetProduct(joysticks):
     for stick in joysticks:
-        pid = joystick.SDL_JoystickGetProduct(stick)
+        pid = sdl2.SDL_JoystickGetProduct(stick)
         assert SDL_GetError() == b""
         if not is_virtual(stick):
             assert pid > 0
 
 def test_SDL_JoystickGetProductVersion(joysticks):
     for stick in joysticks:
-        pver = joystick.SDL_JoystickGetProductVersion(stick)
+        pver = sdl2.SDL_JoystickGetProductVersion(stick)
         assert SDL_GetError() == b""
         assert pver >= 0
 
 @pytest.mark.skipif(sdl2.dll.version < 2014, reason="not available")
 def test_SDL_JoystickGetSerial(joysticks):
     for stick in joysticks:
-        serial = joystick.SDL_JoystickGetSerial(stick)
+        serial = sdl2.SDL_JoystickGetSerial(stick)
         assert SDL_GetError() == b""
         assert serial == None or type(serial) in (str, bytes)
 
 def test_SDL_JoystickGetAxisInitialState(joysticks):
     init_state = c_int16(0)
     for stick in joysticks:
-        for axis in range(joystick.SDL_JoystickNumAxes(stick)):
-            ret = joystick.SDL_JoystickGetAxisInitialState(
+        for axis in range(sdl2.SDL_JoystickNumAxes(stick)):
+            ret = sdl2.SDL_JoystickGetAxisInitialState(
                 stick, axis, byref(init_state)
             )
             assert SDL_GetError() == b""
@@ -295,78 +294,78 @@ def test_SDL_JoystickGetAxisInitialState(joysticks):
 
 def test_SDL_JoystickGetType(joysticks):
     for stick in joysticks:
-        jtype = joystick.SDL_JoystickGetType(stick)
+        jtype = sdl2.SDL_JoystickGetType(stick)
         assert SDL_GetError() == b""
         assert jtype in joystick_types
         if is_virtual(stick):
-            assert jtype == joystick.SDL_JOYSTICK_TYPE_GAMECONTROLLER
+            assert jtype == sdl2.SDL_JOYSTICK_TYPE_GAMECONTROLLER
 
 def test_SDL_JoystickGetDeviceVendor(with_sdl):
-    count = joystick.SDL_NumJoysticks()
+    count = sdl2.SDL_NumJoysticks()
     for index in range(count):
-        vid = joystick.SDL_JoystickGetDeviceVendor(index)
+        vid = sdl2.SDL_JoystickGetDeviceVendor(index)
         assert SDL_GetError() == b""
         if not is_virtual(index):
             assert vid > 0
 
 def test_SDL_JoystickGetDeviceProduct(with_sdl):
-    count = joystick.SDL_NumJoysticks()
+    count = sdl2.SDL_NumJoysticks()
     for index in range(count):
-        pid = joystick.SDL_JoystickGetDeviceProduct(index)
+        pid = sdl2.SDL_JoystickGetDeviceProduct(index)
         assert SDL_GetError() == b""
         if not is_virtual(index):
             assert pid > 0
 
 def test_SDL_JoystickGetDeviceProductVersion(with_sdl):
-    count = joystick.SDL_NumJoysticks()
+    count = sdl2.SDL_NumJoysticks()
     for index in range(count):
-        pver = joystick.SDL_JoystickGetDeviceProductVersion(index)
+        pver = sdl2.SDL_JoystickGetDeviceProductVersion(index)
         assert SDL_GetError() == b""
         assert pver >= 0
 
 def test_SDL_JoystickGetDeviceType(with_sdl):
-    count = joystick.SDL_NumJoysticks()
+    count = sdl2.SDL_NumJoysticks()
     for index in range(count):
-        jtype = joystick.SDL_JoystickGetDeviceType(index)
+        jtype = sdl2.SDL_JoystickGetDeviceType(index)
         assert SDL_GetError() == b""
         assert jtype in joystick_types
         if is_virtual(index):
-            assert jtype == joystick.SDL_JOYSTICK_TYPE_GAMECONTROLLER
+            assert jtype == sdl2.SDL_JOYSTICK_TYPE_GAMECONTROLLER
 
 @pytest.mark.skipif(sdl2.dll.version < 2006, reason="not available")
 def test_SDL_JoystickGetDeviceInstanceID(joysticks):
     for index in range(len(joysticks)):
-        iid = joystick.SDL_JoystickGetDeviceInstanceID(index)
+        iid = sdl2.SDL_JoystickGetDeviceInstanceID(index)
         assert SDL_GetError() == b""
         stick = joysticks[index]
-        assert iid == joystick.SDL_JoystickInstanceID(stick)
+        assert iid == sdl2.SDL_JoystickInstanceID(stick)
 
 @pytest.mark.skipif(sdl2.dll.version < 2007, reason="not available")
 def test_SDL_LockUnlockJoysticks(with_sdl):
     # NOTE: Not sure how to test these more comprehensively
-    joystick.SDL_LockJoysticks()
-    joystick.SDL_UnlockJoysticks()
+    sdl2.SDL_LockJoysticks()
+    sdl2.SDL_UnlockJoysticks()
 
 @pytest.mark.skipif(sdl2.dll.version < 2009, reason="not available")
 def test_SDL_JoystickGetPlayerIndex(joysticks):
     for stick in joysticks:
-        player = joystick.SDL_JoystickGetPlayerIndex(stick)
+        player = sdl2.SDL_JoystickGetPlayerIndex(stick)
         assert player in [-1, 0, 1, 2, 3]
 
 @pytest.mark.skipif(sdl2.dll.version < 2012, reason="not available")
 def test_SDL_JoystickSetPlayerIndex(joysticks):
     i = 0
     for stick in joysticks:
-        joystick.SDL_JoystickSetPlayerIndex(stick, i)
-        player = joystick.SDL_JoystickGetPlayerIndex(stick)
+        sdl2.SDL_JoystickSetPlayerIndex(stick, i)
+        player = sdl2.SDL_JoystickGetPlayerIndex(stick)
         assert player == i
         i += 1
 
 @pytest.mark.skipif(sdl2.dll.version < 2009, reason="not available")
 def test_SDL_JoystickGetDevicePlayerIndex(with_sdl):
-    count = joystick.SDL_NumJoysticks()
+    count = sdl2.SDL_NumJoysticks()
     for index in range(count):
-        player = joystick.SDL_JoystickGetDevicePlayerIndex(index)
+        player = sdl2.SDL_JoystickGetDevicePlayerIndex(index)
         assert player in [-1, 0, 1, 2, 3]
 
 @pytest.mark.skipif(sdl2.dll.version < 2009, reason="not available")
@@ -374,7 +373,7 @@ def test_SDL_JoystickRumble(joysticks):
     # If we ever add an interactive test suite, this should be moved there
     for stick in joysticks:
         # 50% strength low-frequency, 25% high-frequency rumble for 500ms
-        ret = joystick.SDL_JoystickRumble(stick, 32767, 16384, 500)
+        ret = sdl2.SDL_JoystickRumble(stick, 32767, 16384, 500)
         assert ret in [-1, 0]
 
 @pytest.mark.skipif(sdl2.dll.version < 2014, reason="not available")
@@ -382,33 +381,33 @@ def test_SDL_JoystickRumbleTriggers(joysticks):
     # If we ever add an interactive test suite, this should be moved there
     for stick in joysticks:
         # 50% strength left trigger, 25% right trigger rumble for 500ms
-        ret = joystick.SDL_JoystickRumbleTriggers(stick, 32767, 16384, 500)
+        ret = sdl2.SDL_JoystickRumbleTriggers(stick, 32767, 16384, 500)
         assert ret in [-1, 0]
 
 @pytest.mark.skipif(sdl2.dll.version < 2014, reason="not available")
 def test_SDL_JoystickHasSetLED(joysticks):
     # If we ever add an interactive test suite, this should be moved there
     for stick in joysticks:
-        has_led = joystick.SDL_JoystickHasLED(stick)
+        has_led = sdl2.SDL_JoystickHasLED(stick)
         assert has_led in [SDL_FALSE, SDL_TRUE]
         expected = -1 if has_led == SDL_FALSE else 0
         cols = [(255, 0, 0), (0, 255, 0), (0, 0, 255)]
         for r, g, b in cols:
-            ret = joystick.SDL_JoystickSetLED(stick, r, g, b)
+            ret = sdl2.SDL_JoystickSetLED(stick, r, g, b)
             assert ret == expected
 
 @pytest.mark.skipif(sdl2.dll.version < 2018, reason="not available")
 def test_SDL_JoystickHasRumble(joysticks):
     # If we ever add an interactive test suite, this should be moved there
     for stick in joysticks:
-        has_rumble = joystick.SDL_JoystickHasRumble(stick)
+        has_rumble = sdl2.SDL_JoystickHasRumble(stick)
         assert has_rumble in [SDL_FALSE, SDL_TRUE]
 
 @pytest.mark.skipif(sdl2.dll.version < 2018, reason="not available")
 def test_SDL_JoystickHasRumbleTriggers(joysticks):
     # If we ever add an interactive test suite, this should be moved there
     for stick in joysticks:
-        has_rumble_triggers = joystick.SDL_JoystickHasRumbleTriggers(stick)
+        has_rumble_triggers = sdl2.SDL_JoystickHasRumbleTriggers(stick)
         assert has_rumble_triggers in [SDL_FALSE, SDL_TRUE]
 
 @pytest.mark.skip("not implemented")
@@ -420,32 +419,32 @@ def test_SDL_JoystickSendEffect(joysticks):
 
 @pytest.mark.skipif(sdl2.dll.version < 2014, reason="not available")
 def test_SDL_JoystickVirtual(with_sdl):
-    jcount = joystick.SDL_NumJoysticks()
-    jtype = joystick.SDL_JOYSTICK_TYPE_GAMECONTROLLER
-    index = joystick.SDL_JoystickAttachVirtual(jtype, 1, 2, 1)
+    jcount = sdl2.SDL_NumJoysticks()
+    jtype = sdl2.SDL_JOYSTICK_TYPE_GAMECONTROLLER
+    index = sdl2.SDL_JoystickAttachVirtual(jtype, 1, 2, 1)
     assert index >= 0
-    assert joystick.SDL_JoystickIsVirtual(index) == SDL_TRUE
-    assert joystick.SDL_NumJoysticks() == (jcount + 1)
-    stick = joystick.SDL_JoystickOpen(index)
+    assert sdl2.SDL_JoystickIsVirtual(index) == SDL_TRUE
+    assert sdl2.SDL_NumJoysticks() == (jcount + 1)
+    stick = sdl2.SDL_JoystickOpen(index)
     # Test joystick configuration
-    assert joystick.SDL_JoystickNumAxes(stick) == 1
-    assert joystick.SDL_JoystickNumButtons(stick) == 2
-    assert joystick.SDL_JoystickNumHats(stick) == 1
+    assert sdl2.SDL_JoystickNumAxes(stick) == 1
+    assert sdl2.SDL_JoystickNumButtons(stick) == 2
+    assert sdl2.SDL_JoystickNumHats(stick) == 1
     # Try setting and checking for some virtual values
-    assert joystick.SDL_JoystickSetVirtualAxis(stick, 0, -30) == 0
-    assert joystick.SDL_JoystickSetVirtualButton(stick, 0, 255) == 0
-    assert joystick.SDL_JoystickSetVirtualButton(stick, 1, 128) == 0
-    assert joystick.SDL_JoystickSetVirtualHat(stick, 0, 36) == 0
-    joystick.SDL_JoystickUpdate()
+    assert sdl2.SDL_JoystickSetVirtualAxis(stick, 0, -30) == 0
+    assert sdl2.SDL_JoystickSetVirtualButton(stick, 0, 255) == 0
+    assert sdl2.SDL_JoystickSetVirtualButton(stick, 1, 128) == 0
+    assert sdl2.SDL_JoystickSetVirtualHat(stick, 0, 36) == 0
+    sdl2.SDL_JoystickUpdate()
     # NOTE: SDL2 doesn't update joystick values unless it has a window that
     # has input focus. There's a hint to disable that but it doesn't seem to
     # work, so for now these tests are disabled.
-    #assert joystick.SDL_JoystickGetAxis(stick, 0) == -30
-    #assert joystick.SDL_JoystickGetButton(stick, 0) == 255
-    #assert joystick.SDL_JoystickGetButton(stick, 1) == 128
-    #assert joystick.SDL_JoystickGetHat(stick, 0) == 36
+    #assert sdl2.SDL_JoystickGetAxis(stick, 0) == -30
+    #assert sdl2.SDL_JoystickGetButton(stick, 0) == 255
+    #assert sdl2.SDL_JoystickGetButton(stick, 1) == 128
+    #assert sdl2.SDL_JoystickGetHat(stick, 0) == 36
     # Check that removing the virtual joystick works properly
-    joystick.SDL_JoystickClose(stick)
-    jcount = joystick.SDL_NumJoysticks()
-    assert joystick.SDL_JoystickDetachVirtual(index) == 0
-    assert joystick.SDL_NumJoysticks() == (jcount - 1)
+    sdl2.SDL_JoystickClose(stick)
+    jcount = sdl2.SDL_NumJoysticks()
+    assert sdl2.SDL_JoystickDetachVirtual(index) == 0
+    assert sdl2.SDL_NumJoysticks() == (jcount - 1)
